summaryrefslogtreecommitdiff
path: root/MdeModulePkg
diff options
context:
space:
mode:
Diffstat (limited to 'MdeModulePkg')
-rw-r--r--MdeModulePkg/Universal/Acpi/BootScriptExecutorDxe/ScriptExecute.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/MdeModulePkg/Universal/Acpi/BootScriptExecutorDxe/ScriptExecute.c b/MdeModulePkg/Universal/Acpi/BootScriptExecutorDxe/ScriptExecute.c
index d5698d4..c5eec24 100644
--- a/MdeModulePkg/Universal/Acpi/BootScriptExecutorDxe/ScriptExecute.c
+++ b/MdeModulePkg/Universal/Acpi/BootScriptExecutorDxe/ScriptExecute.c
@@ -232,7 +232,7 @@ BootScriptExecutorEntryPoint (
if (EFI_ERROR (Status)) {
//
// This is the first-time loaded by DXE core. reload itself to NVS mem
//
//
// A workaround: Here we install a dummy handle
@@ -265,7 +265,7 @@ BootScriptExecutorEntryPoint (
FfsBuffer = 0xFFFFFFFF;
Status = gBS->AllocatePages (
AllocateMaxAddress,
- EfiACPIMemoryNVS,
+ EfiReservedMemoryType,
Pages,
&FfsBuffer
);
@@ -316,7 +316,7 @@ BootScriptExecutorEntryPoint (
} else {
//
// the entry point is invoked after reloading. following code only run in ACPI NVS
//
BufferSize = sizeof (BOOT_SCRIPT_EXECUTOR_VARIABLE);
@@ -324,7 +324,7 @@ BootScriptExecutorEntryPoint (
Pages = EFI_SIZE_TO_PAGES(BufferSize);
Status = gBS->AllocatePages (
AllocateMaxAddress,
- EfiACPIMemoryNVS,
+ EfiReservedMemoryType,
Pages,
&BootScriptExecutorBuffer
);
@@ -232,7 +232,7 @@ BootScriptExecutorEntryPoint (
if (EFI_ERROR (Status)) {
//
- // This is the first-time loaded by DXE core. reload itself to NVS mem
+ // This is the first-time loaded by DXE core. reload itself to RESERVED mem
//
//
@@ -316,7 +316,7 @@ BootScriptExecutorEntryPoint (
} else {
//
- // the entry point is invoked after reloading. following code only run in ACPI NVS
+ // the entry point is invoked after reloading. following code only run in RESERVED mem
//
BufferSize = sizeof (BOOT_SCRIPT_EXECUTOR_VARIABLE);